@@ -1,26 +1,26 @@
 <?php
+
 /**
- * Zend Framework (http://framework.zend.com/)
- *
- * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2016 Zend Technologies USA Inc. (http://www.zend.com)
- * @license   http://framework.zend.com/license/new-bsd New BSD License
+ * @see       https://github.com/laminas/laminas-code for the canonical source repository
+ * @copyright https://github.com/laminas/laminas-code/blob/master/COPYRIGHT.md
+ * @license   https://github.com/laminas/laminas-code/blob/master/LICENSE.md New BSD License
  */
 
-namespace ZendTest\Code\Generator;
+namespace LaminasTest\Code\Generator;
 
 use DateTime;
+use Laminas\Code\Generator\ClassGenerator;
+use Laminas\Code\Generator\DocBlockGenerator;
+use Laminas\Code\Generator\Exception\ExceptionInterface;
+use Laminas\Code\Generator\Exception\InvalidArgumentException;
+use Laminas\Code\Generator\GeneratorInterface;
+use Laminas\Code\Generator\MethodGenerator;
+use Laminas\Code\Generator\PropertyGenerator;
+use Laminas\Code\Reflection\ClassReflection;
+use LaminasTest\Code\TestAsset\FooClass;
 use PHPUnit\Framework\TestCase;
 use ReflectionMethod;
-use Zend\Code\Generator\ClassGenerator;
-use Zend\Code\Generator\DocBlockGenerator;
-use Zend\Code\Generator\Exception\ExceptionInterface;
-use Zend\Code\Generator\Exception\InvalidArgumentException;
-use Zend\Code\Generator\GeneratorInterface;
-use Zend\Code\Generator\MethodGenerator;
-use Zend\Code\Generator\PropertyGenerator;
-use Zend\Code\NameInformation;
-use Zend\Code\Reflection\ClassReflection;
+use stdClass;
 
 use function current;
 use function fclose;
@@ -28,8 +28,8 @@ use function fopen;
 use function key;
 
 /**
- * @group Zend_Code_Generator
- * @group Zend_Code_Generator_Php
+ * @group Laminas_Code_Generator
+ * @group Laminas_Code_Generator_Php
  */
 class ClassGeneratorTest extends TestCase
 {
@@ -49,7 +49,7 @@ class ClassGeneratorTest extends TestCase
     public function testClassDocBlockAccessors()
     {
         $docBlockGenerator = new DocBlockGenerator();
-        $classGenerator = new ClassGenerator();
+        $classGenerator    = new ClassGenerator();
         $classGenerator->setDocBlock($docBlockGenerator);
         self::assertSame($docBlockGenerator, $classGenerator->getDocBlock());
     }
@@ -150,7 +150,7 @@ class ClassGeneratorTest extends TestCase
         $classGenerator = new ClassGenerator();
 
         $this->expectException(InvalidArgumentException::class);
-        $this->expectExceptionMessage('Zend\Code\Generator\ClassGenerator::addProperty expects string for name');
+        $this->expectExceptionMessage('Laminas\Code\Generator\ClassGenerator::addProperty expects string for name');
         $classGenerator->addProperty(true);
     }
 
@@ -180,7 +180,7 @@ class ClassGeneratorTest extends TestCase
         $classGenerator = new ClassGenerator();
 
         $this->expectException(ExceptionInterface::class);
-        $this->expectExceptionMessage('Zend\Code\Generator\ClassGenerator::addMethod expects string for name');
+        $this->expectExceptionMessage('Laminas\Code\Generator\ClassGenerator::addMethod expects string for name');
 
         $classGenerator->addMethod(true);
     }
@@ -202,7 +202,7 @@ class ClassGeneratorTest extends TestCase
     }
 
     /**
-     * @group ZF-7361
+     * @group Laminas-7361
      */
     public function testHasMethod()
     {
@@ -223,7 +223,7 @@ class ClassGeneratorTest extends TestCase
     }
 
     /**
-     * @group ZF-7361
+     * @group Laminas-7361
      */
     public function testHasProperty()
     {
@@ -246,15 +246,15 @@ class ClassGeneratorTest extends TestCase
     public function testToString()
     {
         $classGenerator = ClassGenerator::fromArray([
-            'name' => 'SampleClass',
-            'flags' => ClassGenerator::FLAG_ABSTRACT,
-            'extendedClass' => 'ExtendedClassName',
+            'name'                  => 'SampleClass',
+            'flags'                 => ClassGenerator::FLAG_ABSTRACT,
+            'extendedClass'         => 'ExtendedClassName',
             'implementedInterfaces' => ['Iterator', 'Traversable'],
-            'properties' => [
+            'properties'            => [
                 'foo',
                 ['name' => 'bar'],
             ],
-            'methods' => [
+            'methods'               => [
                 ['name' => 'baz'],
             ],
         ]);
@@ -262,7 +262,6 @@ class ClassGeneratorTest extends TestCase
         $expectedOutput = <<<EOS
 abstract class SampleClass extends ExtendedClassName implements Iterator, Traversable
 {
-
     public \$foo = null;
 
     public \$bar = null;
@@ -270,8 +269,6 @@ abstract class SampleClass extends ExtendedClassName implements Iterator, Traver
     public function baz()
     {
     }
-
-
 }
 
 EOS;
@@ -281,7 +278,7 @@ EOS;
     }
 
     /**
-     * @group ZF-7909
+     * @group Laminas-7909
      */
     public function testClassFromReflectionThatImplementsInterfaces()
     {
@@ -299,7 +296,7 @@ EOS;
     }
 
     /**
-     * @group ZF-7909
+     * @group Laminas-7909
      */
     public function testClassFromReflectionDiscardParentImplementedInterfaces()
     {
@@ -323,13 +320,13 @@ EOS;
     {
         require_once __DIR__ . '/../TestAsset/NonNamespaceClass.php';
 
-        $reflClass = new ClassReflection('ZendTest_Code_NsTest_BarClass');
+        $reflClass      = new ClassReflection('LaminasTest_Code_NsTest_BarClass');
         $classGenerator = ClassGenerator::fromReflection($reflClass);
         self::assertCount(1, $classGenerator->getMethods());
     }
 
     /**
-     * @group ZF-9602
+     * @group Laminas-9602
      */
     public function testSetextendedclassShouldIgnoreEmptyClassnameOnGenerate()
     {
@@ -341,8 +338,6 @@ EOS;
         $expected = <<<CODE
 class MyClass
 {
-
-
 }
 
 CODE;
@@ -350,7 +345,7 @@ CODE;
     }
 
     /**
-     * @group ZF-9602
+     * @group Laminas-9602
      */
     public function testSetextendedclassShouldNotIgnoreNonEmptyClassnameOnGenerate()
     {
@@ -362,8 +357,6 @@ CODE;
         $expected = <<<CODE
 class MyClass extends ParentClass
 {
-
-
 }
 
 CODE;
@@ -375,17 +368,15 @@ CODE;
      */
     public function testCodeGenerationShouldTakeIntoAccountNamespacesFromReflection()
     {
-        $reflClass = new ClassReflection(TestAsset\ClassWithNamespace::class);
+        $reflClass      = new ClassReflection(TestAsset\ClassWithNamespace::class);
         $classGenerator = ClassGenerator::fromReflection($reflClass);
-        self::assertEquals('ZendTest\Code\Generator\TestAsset', $classGenerator->getNamespaceName());
+        self::assertEquals('LaminasTest\Code\Generator\TestAsset', $classGenerator->getNamespaceName());
         self::assertEquals('ClassWithNamespace', $classGenerator->getName());
         $expected = <<<CODE
-namespace ZendTest\Code\Generator\\TestAsset;
+namespace LaminasTest\Code\Generator\\TestAsset;
 
 class ClassWithNamespace
 {
-
-
 }
 
 CODE;
@@ -468,7 +459,7 @@ CODE;
     }
 
     /**
-     * @group ZF2-151
+     * @group Laminas-151
      */
     public function testAddUses()
     {
@@ -517,7 +508,7 @@ CODE;
     public function testCreateFromArrayWithDocBlockFromArray()
     {
         $classGenerator = ClassGenerator::fromArray([
-            'name' => 'SampleClass',
+            'name'     => 'SampleClass',
             'docblock' => [
                 'shortdescription' => 'foo',
             ],
@@ -530,7 +521,7 @@ CODE;
     public function testCreateFromArrayWithDocBlockInstance()
     {
         $classGenerator = ClassGenerator::fromArray([
-            'name' => 'SampleClass',
+            'name'     => 'SampleClass',
             'docblock' => new DocBlockGenerator('foo'),
         ]);
 
@@ -540,9 +531,9 @@ CODE;
 
     public function testExtendedClassProperies()
     {
-        $reflClass = new ClassReflection(TestAsset\ExtendedClassWithProperties::class);
+        $reflClass      = new ClassReflection(TestAsset\ExtendedClassWithProperties::class);
         $classGenerator = ClassGenerator::fromReflection($reflClass);
-        $code = $classGenerator->generate();
+        $code           = $classGenerator->generate();
         self::assertStringContainsString('publicExtendedClassProperty', $code);
         self::assertStringContainsString('protectedExtendedClassProperty', $code);
         self::assertStringContainsString('privateExtendedClassProperty', $code);
@@ -578,12 +569,9 @@ CODE;
         $expected = <<<CODE
 class MyClass
 {
-
     public function methodOne()
     {
     }
-
-
 }
 
 CODE;
@@ -690,7 +678,7 @@ CODE;
         $classGenerator = new ClassGenerator();
 
         $this->expectException(InvalidArgumentException::class);
-        $classGenerator->addConstant('a', new \stdClass());
+        $classGenerator->addConstant('a', new stdClass());
     }
 
     public function testAddConstantRejectsResourceConstantValue()
@@ -715,7 +703,7 @@ CODE;
         $classGenerator = new ClassGenerator();
 
         $this->expectException(InvalidArgumentException::class);
-        $classGenerator->addConstant('a', [new \stdClass()]);
+        $classGenerator->addConstant('a', [new stdClass()]);
     }
 
     /**
@@ -757,7 +745,7 @@ CODE;
      */
     public function testAddPropertiesIsBackwardsCompatibleWithConstants()
     {
-        $constants = [
+        $constants      = [
             new PropertyGenerator('x', 'value1', PropertyGenerator::FLAG_CONSTANT),
             new PropertyGenerator('y', 'value2', PropertyGenerator::FLAG_CONSTANT),
         ];
@@ -794,14 +782,13 @@ CODE;
         $classGenerator->addConstant('fooProperty', 'duplicate');
 
         $contents = <<<'CODE'
-namespace ZendTest\Code\Generator\TestAsset;
+namespace LaminasTest\Code\Generator\TestAsset;
 
 /**
  * class docblock
  */
 class TestSampleSingleClass
 {
-
     public const fooProperty = 'duplicate';
 
     public $fooProperty = true;
@@ -826,13 +813,11 @@ class TestSampleSingleClass
         /* test test */
         return true;
     }
-
-
 }
 
 CODE;
 
-        self::assertEquals($classGenerator->generate(), $contents);
+        self::assertEquals($contents, $classGenerator->generate());
     }
 
     /**
@@ -840,9 +825,9 @@ CODE;
      */
     public function testHereDoc()
     {
-        $reflector = new ClassReflection(TestAsset\TestClassWithHeredoc::class);
+        $reflector      = new ClassReflection(TestAsset\TestClassWithHeredoc::class);
         $classGenerator = new ClassGenerator();
-        $methods = $reflector->getMethods();
+        $methods        = $reflector->getMethods();
         $classGenerator->setName('OutputClass');
 
         foreach ($methods as $method) {
@@ -851,10 +836,9 @@ CODE;
             $classGenerator->addMethodFromGenerator($methodGenerator);
         }
 
-        $contents = <<< 'CODE'
+        $contents = <<<'CODE'
 class OutputClass
 {
-
     public function someFunction()
     {
         $output = <<< END
@@ -864,8 +848,6 @@ class OutputClass
                 Fix it, fix it!
 END;
     }
-
-
 }
 
 CODE;
@@ -1117,14 +1099,11 @@ CODE;
         $output = <<<'CODE'
 class myClass
 {
-
     use myTrait, hisTrait, thatTrait;
-
-
 }
 
 CODE;
-        self::assertEquals($classGenerator->generate(), $output);
+        self::assertEquals($output, $classGenerator->generate());
     }
 
     /**
@@ -1143,33 +1122,28 @@ CODE;
         $output = <<<'CODE'
 class myClass
 {
-
     use myTrait, hisTrait, thatTrait {
         hisTrait::foo as public test;
         myTrait::bar insteadof hisTrait;
         myTrait::bar insteadof thatTrait;
 
     }
-
-
 }
 
 CODE;
-        self::assertEquals($classGenerator->generate(), $output);
+        self::assertEquals($output, $classGenerator->generate());
     }
 
     public function testGenerateWithFinalFlag()
     {
         $classGenerator = ClassGenerator::fromArray([
-            'name' => 'SomeClass',
+            'name'  => 'SomeClass',
             'flags' => ClassGenerator::FLAG_FINAL,
         ]);
 
         $expectedOutput = <<<EOS
 final class SomeClass
 {
-
-
 }
 
 EOS;
@@ -1183,9 +1157,9 @@ EOS;
         $classGenerator = new ClassGenerator();
         $classGenerator->setName('ClassName');
         $classGenerator->setNamespaceName('SomeNamespace');
-        $classGenerator->addUse(NameInformation::class);
-        $classGenerator->setExtendedClass(NameInformation::class);
-        self::assertStringContainsString('class ClassName extends NameInformation', $classGenerator->generate());
+        $classGenerator->addUse(FooClass::class);
+        $classGenerator->setExtendedClass(FooClass::class);
+        self::assertStringContainsString('class ClassName extends FooClass', $classGenerator->generate());
     }
 
     /**
@@ -1279,9 +1253,9 @@ EOS;
         $classGenerator->setNamespaceName('SomeNamespace');
         $classGenerator->addUse(GeneratorInterface::class);
         $classGenerator->setImplementedInterfaces([
-           'SomeNamespace\ClassInterface',
-           GeneratorInterface::class,
-           'Iteratable',
+            'SomeNamespace\ClassInterface',
+            GeneratorInterface::class,
+            'Iteratable',
         ]);
 
         $expected = 'class ClassName implements ClassInterface, GeneratorInterface, \Iteratable';
