@@ -1,30 +1,34 @@
 <?php
+
 /**
- * Zend Framework (http://framework.zend.com/)
- *
- * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2016 Zend Technologies USA Inc. (http://www.zend.com)
- * @license   http://framework.zend.com/license/new-bsd New BSD License
+ * @see       https://github.com/laminas/laminas-code for the canonical source repository
+ * @copyright https://github.com/laminas/laminas-code/blob/master/COPYRIGHT.md
+ * @license   https://github.com/laminas/laminas-code/blob/master/LICENSE.md New BSD License
  */
 
-namespace ZendTest\Code\Generator;
+namespace LaminasTest\Code\Generator;
 
+use Closure;
+use Laminas\Code\Generator\ParameterGenerator;
+use Laminas\Code\Generator\ValueGenerator;
+use Laminas\Code\Reflection\ClassReflection;
+use Laminas\Code\Reflection\MethodReflection;
+use Laminas\Code\Reflection\ParameterReflection;
+use LaminasTest\Code\Generator\TestAsset\ParameterClass;
+use LaminasTest\Code\TestAsset\ClassTypeHintedClass;
+use LaminasTest\Code\TestAsset\DocBlockOnlyHintsClass;
+use LaminasTest\Code\TestAsset\EmptyClass;
+use LaminasTest\Code\TestAsset\InternalHintsClass;
+use LaminasTest\Code\TestAsset\IterableHintsClass;
+use LaminasTest\Code\TestAsset\NullableHintsClass;
+use LaminasTest\Code\TestAsset\NullNullableDefaultHintsClass;
+use LaminasTest\Code\TestAsset\ObjectHintsClass;
+use LaminasTest\Code\TestAsset\Php80Types;
+use LaminasTest\Code\TestAsset\VariadicParametersClass;
+use Phar;
 use PHPUnit\Framework\TestCase;
-use Zend\Code\Generator\ParameterGenerator;
-use Zend\Code\Generator\ValueGenerator;
-use Zend\Code\Reflection\ClassReflection;
-use Zend\Code\Reflection\MethodReflection;
-use Zend\Code\Reflection\ParameterReflection;
-use ZendTest\Code\Generator\TestAsset\ParameterClass;
-use ZendTest\Code\TestAsset\ClassTypeHintedClass;
-use ZendTest\Code\TestAsset\DocBlockOnlyHintsClass;
-use ZendTest\Code\TestAsset\EmptyClass;
-use ZendTest\Code\TestAsset\InternalHintsClass;
-use ZendTest\Code\TestAsset\IterableHintsClass;
-use ZendTest\Code\TestAsset\NullableHintsClass;
-use ZendTest\Code\TestAsset\NullNullableDefaultHintsClass;
-use ZendTest\Code\TestAsset\ObjectHintsClass;
-use ZendTest\Code\TestAsset\VariadicParametersClass;
+use ReflectionProperty;
+use stdClass;
 
 use function array_combine;
 use function array_filter;
@@ -34,9 +38,11 @@ use function ltrim;
 use function strpos;
 use function strtolower;
 
+use const PHP_VERSION_ID;
+
 /**
- * @group Zend_Code_Generator
- * @group Zend_Code_Generator_Php
+ * @group Laminas_Code_Generator
+ * @group Laminas_Code_Generator_Php
  */
 class ParameterGeneratorTest extends TestCase
 {
@@ -85,7 +91,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetParameterName()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('name');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertEquals('param', $codeGenParam->getName());
     }
@@ -93,7 +99,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetParameterType()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('type');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertEquals('stdClass', $codeGenParam->getType());
     }
@@ -101,7 +107,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetReference()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('reference');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertTrue($codeGenParam->getPassedByReference());
     }
@@ -109,7 +115,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetDefaultValue()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('defaultValue');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         $defaultValue = $codeGenParam->getDefaultValue();
         self::assertEquals('\'foo\'', (string) $defaultValue);
@@ -134,7 +140,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetArrayHint()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('fromArray');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertEquals('array', $codeGenParam->getType());
     }
@@ -142,7 +148,7 @@ class ParameterGeneratorTest extends TestCase
     public function testFromReflectionGetWithNativeType()
     {
         $reflectionParameter = $this->getFirstReflectionParameter('hasNativeDocTypes');
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertNotEquals('int', $codeGenParam->getType());
         self::assertEquals('', $codeGenParam->getType());
@@ -159,19 +165,22 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @dataProvider dataFromReflectionGenerate
-     *
      * @param string $methodName
      * @param string $expectedCode
      */
     public function testFromReflectionGenerate($methodName, $expectedCode)
     {
         $reflectionParameter = $this->getFirstReflectionParameter($methodName);
-        $codeGenParam = ParameterGenerator::fromReflection($reflectionParameter);
+        $codeGenParam        = ParameterGenerator::fromReflection($reflectionParameter);
 
         self::assertEquals($expectedCode, $codeGenParam->generate());
     }
 
-    public function dataFromReflectionGenerate()
+    /**
+     * @return string[][]
+     * @psalm-return non-empty-list<array{non-empty-string, non-empty-string}>
+     */
+    public function dataFromReflectionGenerate(): array
     {
         return [
             ['name', '$param'],
@@ -198,8 +207,8 @@ class ParameterGeneratorTest extends TestCase
      */
     protected function getFirstReflectionParameter($method)
     {
-        $reflectionClass = new ClassReflection(TestAsset\ParameterClass::class);
-        $method = $reflectionClass->getMethod($method);
+        $reflectionClass = new ClassReflection(ParameterClass::class);
+        $method          = $reflectionClass->getMethod($method);
 
         $params = $method->getParameters();
 
@@ -211,7 +220,7 @@ class ParameterGeneratorTest extends TestCase
         $parameterGenerator = ParameterGenerator::fromArray([
             'name'              => 'SampleParameter',
             'type'              => 'int',
-            'defaultvalue'      => 'foo',
+            'defaultvalue'      => 'default-foo',
             'passedbyreference' => false,
             'position'          => 1,
             'sourcedirty'       => false,
@@ -228,7 +237,13 @@ class ParameterGeneratorTest extends TestCase
         self::assertFalse($parameterGenerator->isSourceDirty());
         self::assertEquals('foo', $parameterGenerator->getSourceContent());
         self::assertEquals('-', $parameterGenerator->getIndentation());
-        self::assertAttributeEquals(true, 'omitDefaultValue', $parameterGenerator);
+        self::assertStringNotContainsString('default-foo', $parameterGenerator->generate());
+
+        $reflectionOmitDefaultValue = new ReflectionProperty($parameterGenerator, 'omitDefaultValue');
+
+        $reflectionOmitDefaultValue->setAccessible(true);
+
+        self::assertTrue($reflectionOmitDefaultValue->getValue($parameterGenerator));
     }
 
     /**
@@ -238,12 +253,12 @@ class ParameterGeneratorTest extends TestCase
     {
         require_once __DIR__ . '/../TestAsset/NonNamespaceClass.php';
 
-        $reflClass = new ClassReflection('ZendTest_Code_NsTest_BarClass');
-        $params = $reflClass->getMethod('fooMethod')->getParameters();
+        $reflClass = new ClassReflection('LaminasTest_Code_NsTest_BarClass');
+        $params    = $reflClass->getMethod('fooMethod')->getParameters();
 
         $param = ParameterGenerator::fromReflection($params[0]);
 
-        self::assertEquals('ZendTest_Code_NsTest_BarClass', $param->getType());
+        self::assertEquals('LaminasTest_Code_NsTest_BarClass', $param->getType());
     }
 
     /**
@@ -254,7 +269,7 @@ class ParameterGeneratorTest extends TestCase
         require_once __DIR__ . '/TestAsset/NamespaceTypeHintClass.php';
 
         $reflClass = new ClassReflection('Namespaced\TypeHint\Bar');
-        $params = $reflClass->getMethod('method')->getParameters();
+        $params    = $reflClass->getMethod('method')->getParameters();
 
         $param = ParameterGenerator::fromReflection($params[0]);
 
@@ -263,7 +278,6 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group 6023
-     *
      * @coversNothing
      */
     public function testGeneratedParametersHaveEscapedDefaultValues()
@@ -279,9 +293,7 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group zendframework/zend-code#29
-     *
      * @dataProvider simpleHints
-     *
      * @param string $type
      * @param string $expectedType
      */
@@ -324,9 +336,7 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group zendframework/zend-code#29
-     *
      * @dataProvider validClassName
-     *
      * @param string $className
      */
     public function testTypeHintWithValidClassName($className)
@@ -354,9 +364,6 @@ class ParameterGeneratorTest extends TestCase
             ['baz\\tab'],
             ['baz\\tab\\taz'],
             ['baz\\tab\\taz1'],
-            ['mixed'],
-            ['Mixed'],
-            ['MIXED'],
             ['resource'],
             ['Resource'],
             ['RESOURCE'],
@@ -365,9 +372,7 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group zendframework/zend-code#29
-     *
      * @dataProvider reflectionHints
-     *
      * @param string      $className
      * @param string      $methodName
      * @param string      $parameterName
@@ -391,9 +396,7 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group zendframework/zend-code#29
-     *
      * @dataProvider reflectionHints
-     *
      * @param string      $className
      * @param string      $methodName
      * @param string      $parameterName
@@ -459,8 +462,8 @@ class ParameterGeneratorTest extends TestCase
             [ClassTypeHintedClass::class, 'parentParameter', 'foo', '\\' . EmptyClass::class],
             [ClassTypeHintedClass::class, 'classParameter', 'foo', '\\' . ClassTypeHintedClass::class],
             [ClassTypeHintedClass::class, 'otherClassParameter', 'foo', '\\' . InternalHintsClass::class],
-            [ClassTypeHintedClass::class, 'closureParameter', 'foo', '\\' . \Closure::class],
-            [ClassTypeHintedClass::class, 'importedClosureParameter', 'foo', '\\' . \Closure::class],
+            [ClassTypeHintedClass::class, 'closureParameter', 'foo', '\\' . Closure::class],
+            [ClassTypeHintedClass::class, 'importedClosureParameter', 'foo', '\\' . Closure::class],
             [DocBlockOnlyHintsClass::class, 'arrayParameter', 'foo', null],
             [DocBlockOnlyHintsClass::class, 'callableParameter', 'foo', null],
             [DocBlockOnlyHintsClass::class, 'intParameter', 'foo', null],
@@ -502,9 +505,7 @@ class ParameterGeneratorTest extends TestCase
 
     /**
      * @group zendframework/zend-code#29
-     *
      * @dataProvider variadicHints
-     *
      * @param string $className
      * @param string $methodName
      * @param string $parameterName
@@ -580,11 +581,75 @@ class ParameterGeneratorTest extends TestCase
      */
     public function testGetInternalClassDefaultParameterValue()
     {
-        $parameter = ParameterGenerator::fromReflection(new ParameterReflection([\Phar::class, 'compress'], 1));
+        $parameter = ParameterGenerator::fromReflection(new ParameterReflection([Phar::class, 'compress'], 1));
 
         self::assertSame('null', strtolower((string) $parameter->getDefaultValue()));
     }
 
+    /**
+     * @requires PHP >= 8.0
+     * @group laminas/laminas-code#53
+     * @dataProvider php80Methods
+     * @psalm-param class-string $className
+     * @psalm-param non-empty-string $method
+     * @psalm-param positive-int|0 $parameterIndex
+     * @psalm-param non-empty-string $expectedGeneratedSignature
+     */
+    public function testGeneratedSignatureForPhp80ParameterType(
+        string $className,
+        string $method,
+        int $parameterIndex,
+        string $expectedType,
+        string $expectedGeneratedSignature
+    ): void {
+        $parameter = ParameterGenerator::fromReflection(
+            new ParameterReflection([$className, $method], $parameterIndex)
+        );
+
+        self::assertSame($expectedType, $parameter->getType());
+        self::assertSame($expectedGeneratedSignature, $parameter->generate());
+    }
+
+    /**
+     * @psalm-return non-empty-list<array{class-string, non-empty-string, positive-int|0, string, non-empty-string}>
+     */
+    public function php80Methods(): array
+    {
+        return [
+            [Php80Types::class, 'mixedType', 0, 'mixed', 'mixed $parameter'],
+            [
+                Php80Types::class,
+                'falseType',
+                0,
+                Php80Types::class . '|false',
+                '\\' . Php80Types::class . '|false $parameter',
+            ],
+            [Php80Types::class, 'unionNullableType', 0, 'bool', '?bool $parameter'],
+            [Php80Types::class, 'unionReverseNullableType', 0, 'bool', '?bool $parameter'],
+            [
+                Php80Types::class,
+                'unionNullableTypeWithDefaultValue',
+                0,
+                'bool|string|null',
+                'bool|string|null $parameter = null',
+            ],
+            [
+                Php80Types::class,
+                'unionType',
+                0,
+                Php80Types::class . '|' . stdClass::class,
+                '\\' . Php80Types::class . '|\\' . stdClass::class . ' $parameter',
+            ],
+            [
+                Php80Types::class,
+                'selfAndBoolType',
+                0,
+                Php80Types::class . '|bool',
+                '\\' . Php80Types::class . '|bool $parameter',
+            ],
+        ];
+    }
+
     public function testOmitType()
     {
         $parameter = new ParameterGenerator('foo', 'string', 'bar');
