@@ -1,11 +1,12 @@
 <?php
+
 /**
  * File header here
  *
  * @author Ralph Schindler <ralph.schindler@zend.com>
  */
 
-namespace ZendTest\Code\Generator\TestAsset;
+namespace LaminasTest\Code\Generator\TestAsset;
 
 /**
  * class docblock
