@@ -1,29 +1,26 @@
 <?php
+
 /**
- * Zend Framework (http://framework.zend.com/)
- *
- * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2016 Zend Technologies USA Inc. (http://www.zend.com)
- * @license   http://framework.zend.com/license/new-bsd New BSD License
+ * @see       https://github.com/laminas/laminas-code for the canonical source repository
+ * @copyright https://github.com/laminas/laminas-code/blob/master/COPYRIGHT.md
+ * @license   https://github.com/laminas/laminas-code/blob/master/LICENSE.md New BSD License
  */
 
-namespace ZendTest\Code\Reflection\DocBlock\Tag;
+namespace LaminasTest\Code\Reflection\DocBlock\Tag;
 
+use Laminas\Code\Reflection\DocBlock\Tag\AuthorTag;
 use PHPUnit\Framework\TestCase;
-use Zend\Code\Reflection\DocBlock\Tag\AuthorTag;
 
 /**
- * @group      Zend_Reflection
- * @group      Zend_Reflection_DocBlock
+ * @group      Laminas_Reflection
+ * @group      Laminas_Reflection_DocBlock
  */
 class AuthorTagTest extends TestCase
 {
-    /**
-     * @var AuthorTag
-     */
+    /** @var AuthorTag */
     protected $tag;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->tag = new AuthorTag();
     }
