@@ -1,17 +1,16 @@
 <?php
+
 /**
- * Zend Framework (http://framework.zend.com/)
- *
- * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2016 Zend Technologies USA Inc. (http://www.zend.com)
- * @license   http://framework.zend.com/license/new-bsd New BSD License
+ * @see       https://github.com/laminas/laminas-code for the canonical source repository
+ * @copyright https://github.com/laminas/laminas-code/blob/master/COPYRIGHT.md
+ * @license   https://github.com/laminas/laminas-code/blob/master/LICENSE.md New BSD License
  */
 
-namespace ZendTest\Code\Reflection\TestAsset;
+namespace LaminasTest\Code\Reflection\TestAsset;
 
 /***
  * /!\ Don't fix this file with the coding style.
- * The class Zend\Code\Reflection\FunctionReflection must parse a lot of closure formats
+ * The class Laminas\Code\Reflection\FunctionReflection must parse a lot of closure formats
  */
 
 function function1()
@@ -21,7 +20,7 @@ function function1()
 
 
 /**
- * Zend Function Two
+ * Laminas Function Two
  *
  * This is the long description for function two
  *
